exceptiontools.StaffContainmentError
====================================

.. inheritance-diagram:: abjad.tools.exceptiontools.StaffContainmentError.StaffContainmentError
   :private-bases:

.. autoclass:: abjad.tools.exceptiontools.StaffContainmentError.StaffContainmentError

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.StaffContainmentError.StaffContainmentError.__delattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.StaffContainmentError.StaffContainmentError.__getitem__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.StaffContainmentError.StaffContainmentError.__getslice__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.StaffContainmentError.StaffContainmentError.__repr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.StaffContainmentError.StaffContainmentError.__setattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.StaffContainmentError.StaffContainmentError.__setstate__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.StaffContainmentError.StaffContainmentError.__str__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.StaffContainmentError.StaffContainmentError.__unicode__

    Inherited from :py:class:`exceptions.BaseException`
